=============
Sage Explorer
=============

A `Jupyter Notebook <http://jupyter.org>`_ widget for exploring `SageMath <http://www.sagemath.org>`_ objects.

To use this module, you need to import it::

    from sage_explorer import explore

This work is licensed under a `Creative Commons Attribution-Share Alike
3.0 License`__.

__ https://creativecommons.org/licenses/by-sa/3.0/

Sage Explorer
=============

.. toctree::
   :maxdepth: 2
   :glob:

   *

Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
